bpplot <- function(..., names = 0, main = "Box-Percentile Plot", xlab = "", ylab = 
	"Percentiles", population = F)
{
	all.x <- list(...)	
	if (is.list(all.x[[1]])) {
		all.x <- all.x[[1]]
	}
	labels <- names(all.x)
	n <- length(all.x)
	centers <- seq(from = 0, by = 1.2, length = n)
	ymax <- max(sapply(all.x, max))
	ymin <- min(sapply(all.x, min))
	xmax <- max(centers) + 0.5
	xmin <- -0.5
	plot(c(xmin, xmax), c(ymin, ymax), type = "n", main = main, xlab = xlab,
		ylab = ylab, xaxt = "n")
	for(i in 1:n) {
		plot.values <- bpx(all.x[[i]], centers[i], population)
		lines(plot.values$x1, plot.values$y1)
		lines(plot.values$x2, plot.values$y2)
		lines(plot.values$q1.x, plot.values$q1.y)
		lines(plot.values$q3.x, plot.values$q3.y)
		lines(plot.values$med.x, plot.values$med.y)
	}
	if(names == 0 & length(labels) == 0) {
		temp <- sapply(substitute(list(...)), deparse)[-1]
		if (length(temp) == length(centers)) {labels <- temp}
		}
	if(names != 0) {axis(1, centers, names)}
	else {
		if(names == 0 & length(labels) == 0) {axis(1, centers, 1:n)}
		else {axis(1, centers, labels)}
		}
	invisible(centers)
}

bpx <- function(y, offset, population)
{
	n <- length(y)
	indexq1 <- round(n*.25)
	indexq3 <- round(n*.75)
	if (population) {
		delta <- 1/(n - 1)
		prob <- seq(0, 1, delta)
		}
	else {
		delta <- 1/(n + 1)
		prob <- seq(delta, 1 - delta, delta)
		}
	
	quan <- sort(y)
	Quartiles <- fivenum(y)
	med <- Quartiles[3]
	q1 <- Quartiles[2]
	q3 <- Quartiles[4]  
	first.half.p <- prob[quan <= med]
	second.half.p <- 1 - prob[quan > med]
	plotx <- c(first.half.p, second.half.p)	

###
# calculating the ends of the first quartile line
###
	qx <- plotx[indexq1]
	q1.x <- c( - qx, qx) + offset
###
# calculating the ends of the third quartile line
###
	qx <- plotx[indexq3]
	q3.x <- c( - qx, qx) + offset
	q1.y <- c(q1, q1)
	q3.y <- c(q3, q3)
	med.x <- c( - max(first.half.p), max(first.half.p)) + offset
	med.y <- c(med, med)
	return(list(x1 = ( - plotx) + offset, y1 = quan, x2 = plotx + offset,
		y2 = quan, q1.y = q1.y, q1.x = q1.x, q3.y = q3.y, q3.x = q3.x,
		med.y = med.y, med.x = med.x))
}
